summaryrefslogtreecommitdiff
path: root/gdb/gdbarch.sh
diff options
context:
space:
mode:
authorUlrich Weigand <uweigand@de.ibm.com>2010-07-06 12:56:21 +0000
committerUlrich Weigand <uweigand@de.ibm.com>2010-07-06 12:56:21 +0000
commitef4ae4726524130b1cc946be6e8df9fb7747f637 (patch)
tree6c6d3cc1d74e1d9b672108e9be280bc3208bf53a /gdb/gdbarch.sh
parentd844331d1658deb89d66b7090cb6f4db623cd767 (diff)
downloadgdb-ef4ae4726524130b1cc946be6e8df9fb7747f637.tar.gz
include/ChangeLog:
2010-07-06 Ken Werner <ken.werner@de.ibm.com> * floatformat.h (floatformat_ieee_half_big): Add declaration. (floatformat_ieee_half_little): Likewise. libiberty/ChangeLog: 2010-07-06 Ken Werner <ken.werner@de.ibm.com> * floatformat.c (floatformat_ieee_half_big): New variable. (floatformat_ieee_half_little): Likewise. gdb/ChangeLog: 2010-07-06 Ken Werner <ken.werner@de.ibm.com> * gdbtypes.h (floatformats_ieee_half): Add declaration. * gdbtypes.c (floatformats_ieee_half): New variable. * doublest.c (floatformat_from_length): Set format to gdbarch_half_format if length matches. * gdbarch.sh (half_bit): New architecture method. (half_format): Likewise. * gdbarch.h: Regenerate. * gdbarch.c: Likewise.
Diffstat (limited to 'gdb/gdbarch.sh')
-rwxr-xr-xgdb/gdbarch.sh8
1 files changed, 5 insertions, 3 deletions
diff --git a/gdb/gdbarch.sh b/gdb/gdbarch.sh
index 1e9a4893831..eece393c990 100755
--- a/gdb/gdbarch.sh
+++ b/gdb/gdbarch.sh
@@ -363,12 +363,14 @@ v:int:long_bit:::8 * sizeof (long):4*TARGET_CHAR_BIT::0
# machine.
v:int:long_long_bit:::8 * sizeof (LONGEST):2*gdbarch->long_bit::0
# The ABI default bit-size and format for "float", "double", and "long
# double". These bit/format pairs should eventually be combined into
# a single object. For the moment, just initialize them as a pair.
# Each format describes both the big and little endian layouts (if
# useful).
+v:int:half_bit:::16:2*TARGET_CHAR_BIT::0
+v:const struct floatformat **:half_format:::::floatformats_ieee_half::pformat (gdbarch->half_format)
v:int:float_bit:::8 * sizeof (float):4*TARGET_CHAR_BIT::0
v:const struct floatformat **:float_format:::::floatformats_ieee_single::pformat (gdbarch->float_format)
v:int:double_bit:::8 * sizeof (double):8*TARGET_CHAR_BIT::0
@@ -363,12 +363,14 @@ v:int:long_bit:::8 * sizeof (long):4*TARGET_CHAR_BIT::0
# machine.
v:int:long_long_bit:::8 * sizeof (LONGEST):2*gdbarch->long_bit::0
-# The ABI default bit-size and format for "float", "double", and "long
-# double". These bit/format pairs should eventually be combined into
-# a single object. For the moment, just initialize them as a pair.
+# The ABI default bit-size and format for "half", "float", "double", and
+# "long double". These bit/format pairs should eventually be combined
+# into a single object. For the moment, just initialize them as a pair.
# Each format describes both the big and little endian layouts (if
# useful).